@@ -1,9 +1,8 @@
 //! Detect whether the changelog should be updated.
-use breezyshim::branch::Branch;
 use breezyshim::error::Error;
-use breezyshim::graph::{Error as GraphError, Graph};
+use breezyshim::graph::Graph;
+use breezyshim::prelude::*;
 use breezyshim::revisionid::RevisionId;
-use breezyshim::tree::{Tree, WorkingTree};
 use debian_changelog::{ChangeLog, Entry as ChangeLogEntry};
 use lazy_regex::regex;
 
@@ -72,7 +71,7 @@ fn gbp_conf_has_dch_section(tree: &dyn Tree, debian_path: &std::path::Path) -> b
 /// * `True` if the changelog should be updated
 /// * `False` if the changelog should not be updated
 pub fn guess_update_changelog(
-    tree: &WorkingTree,
+    tree: &dyn WorkingTree,
     debian_path: &std::path::Path,
     mut cl: Option<ChangeLog>,
 ) -> Option<ChangelogBehaviour> {
@@ -119,7 +118,7 @@ pub fn guess_update_changelog(
     if let Some(ret) = guess_update_changelog_from_tree(tree, debian_path, cl) {
         Some(ret)
     } else {
-        guess_update_changelog_from_branch(tree.branch().as_ref(), debian_path, None)
+        guess_update_changelog_from_branch(&tree.branch(), debian_path, None)
     }
 }
 
@@ -153,18 +152,25 @@ pub fn guess_update_changelog_from_tree(
 
 fn greedy_revisions(graph: &Graph, revid: &RevisionId, length: usize) -> (Vec<RevisionId>, bool) {
     let mut ret = vec![];
-    let mut it = graph.iter_lefthand_ancestry(revid, None);
+    let mut it = match graph.iter_lefthand_ancestry(revid, None) {
+        Ok(iter) => iter,
+        Err(_) => return (ret, true),
+    };
     while ret.len() < length {
         ret.push(match it.next() {
             None => break,
             Some(Ok(rev)) => rev,
-            Some(Err(GraphError::RevisionNotPresent(_))) => {
+            Some(Err(Error::RevisionNotPresent(_))) => {
                 if !ret.is_empty() {
                     ret.pop();
                 }
                 // Shallow history
                 return (ret, true);
             }
+            Some(Err(e)) => {
+                // Re-raise other errors
+                panic!("Error iterating through ancestry: {:?}", e);
+            }
         });
     }
     (ret, false)
@@ -205,30 +211,16 @@ fn changelog_stats(
             .repository()
             .get_revision_deltas(revs.as_slice(), None),
     ) {
-        let mut filenames = vec![];
-        for a in delta.added {
-            if let Some(p) = a.path.1 {
-                filenames.push(p.clone());
-            }
-        }
-        for r in delta.removed {
-            if let Some(p) = r.path.0 {
-                filenames.push(p.clone());
-            }
-        }
-        for r in delta.renamed {
-            if let Some(p) = r.path.0 {
-                filenames.push(p.clone());
-            }
-            if let Some(p) = r.path.1 {
-                filenames.push(p.clone());
-            }
-        }
-        for m in delta.modified {
-            if let Some(p) = m.path.0 {
-                filenames.push(p.clone());
-            }
-        }
+        let filenames: Vec<_> = delta
+            .added
+            .iter()
+            .filter_map(|a| a.path.1.as_ref())
+            .chain(delta.removed.iter().filter_map(|r| r.path.0.as_ref()))
+            .chain(delta.renamed.iter().filter_map(|r| r.path.0.as_ref()))
+            .chain(delta.renamed.iter().filter_map(|r| r.path.1.as_ref()))
+            .chain(delta.modified.iter().filter_map(|m| m.path.0.as_ref()))
+            .cloned()
+            .collect();
         if !filenames.iter().any(|f| f.starts_with(debian_path)) {
             continue;
         }
@@ -645,7 +637,7 @@ blah (0.20.1) unstable; urgency=medium
 "#,
         )
         .unwrap();
-        tree.add(&[&Path::new("debian"), &Path::new("debian/changelog")])
+        tree.add(&[Path::new("debian"), Path::new("debian/changelog")])
             .unwrap();
         assert_eq!(
             Some(ChangelogBehaviour {
